package rm;

import java.math.BigInteger;
import java.util.Arrays;
import java.util.List;

public class AddOne implements Instruction {

	private final int regId;
	private final IntegerLabel jumpLabel;
	
	public AddOne(int regId, int jumpLabel) {
		this.regId = regId;
		this.jumpLabel = new IntegerLabel(jumpLabel);
	}
	
	@Override
	public Label execute(RegisterConfiguration config) {
		BigInteger a = config.getRegister(regId);
		config.setRegister(regId, a.add(BigInteger.ONE));
		return jumpLabel;
	}

	@Override
	public List<Label> getAccessingLabels() {
		return Arrays.asList(jumpLabel);
	}

	@Override
	public List<Integer> getAccessingRegisters() {
		return Arrays.asList(regId);
	}
	
	@Override
	public String toString() {
		return "R" + regId + "+ -> L" + jumpLabel.labelId;
	}

}
